# Copyright (C) 2021-2023 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

FILESEXTRAPATHS:prepend := "${THISDIR}/${PN}:"

FWDIR = "${nonarch_base_libdir}/firmware"

COMPATIBLE_MACHINE:append = "|mpxs32g"

NXP_FIRMWARE_LOCAL_DIR:s32g2 := "${THISDIR}/${PN}/s32g2"
NXP_FIRMWARE_LOCAL_DIR:s32g3 := "${THISDIR}/${PN}/s32g3"

LIC_FILES_CHKSUM += "file://LLCE-License.txt;md5=3efaacbb2298460a2345c5950a9ebb6a"

SRC_URI += "file://LLCE-License.txt"

# Place ${PN}-rtw88 in the list of packages
# Important note: the package needs to be prepended with '=+',
# because the main package ${PN} *has to be* the last package
# in the list.
# Background: finally, the recipe linux-firmware_*.bb will grab
# *all* files in ${FWDIR}:
# > FILES:${PN} += "${nonarch_base_libdir}/firmware/*"
# If a package is listed after ${PN} then there are no more files
# left.
PACKAGES =+ "${@bb.utils.contains('DISTRO_FEATURES', \
    'wifi', \
    ' ${PN}-rtw88 ', \
    '', d)}"

do_populate_lic:prepend() {
    import os
    import shutil

    shutil.copy2(os.path.join(d.getVar("NXP_FIRMWARE_LOCAL_DIR"),
                              "LLCE-License.txt"),
                 os.path.join(d.getVar("S"), "LLCE-License.txt"))
}

do_install:prepend() {
    if ${@bb.utils.contains('DISTRO_FEATURES', 'llce-can', 'true', 'false', d)}; then
       mkdir -p ${D}${FWDIR}
       install -m 0644 ${NXP_FIRMWARE_LOCAL_DIR}/dte.bin ${D}${FWDIR}/dte.bin
       install -m 0644 ${NXP_FIRMWARE_LOCAL_DIR}/frpe.bin ${D}${FWDIR}/frpe.bin
       install -m 0644 ${NXP_FIRMWARE_LOCAL_DIR}/ppe_tx.bin ${D}${FWDIR}/ppe_tx.bin
       install -m 0644 ${NXP_FIRMWARE_LOCAL_DIR}/ppe_rx.bin ${D}${FWDIR}/ppe_rx.bin
    fi
}

FILES:${PN}-rtw88 = "${FWDIR}/rtw88/rtw8822*.bin"
